==> cordova-sqlite-react-1.1.5.tgz: package/SqliteClass/SLStore.ts <==
import { setItemT, getItemT } from './../@types/commonType';
import { returnGetDataSqliteT } from '../@types/commonType';
import { Sqlite } from './Sqlite';
//INFO: Возможно в будущем localStorage переделать на sqlite3 для pc
  /*
    Структура хранения настроек как в Sqlite так и в localeStorage
    1й вариант. name: 'config' value: "{}", name: 'DarkMode', value: 'true'. В localStorage "config": "{}"
        При каждом внесении изменений придётся доставать, парсить, изменять, закидывать в string и обратно сохранять пачку.
        При выходе удалить ключ config, не затрагивая DarkMode, закинуть default config в state 
    2й вариант. 
      Сохранять каждый ключ   name: "isAuth", value: "true"  в sqlite.  в localeStorage будет так "isAuth": "true"
      Неудобства: 
        Первоначальное получение данных и преобразование в структуру state
        Для поддержания одинаковых ключей в sqlite и localStorage придётся, при удалении ненужных ключей иметь массив нужных
        ключей которые ненужно удалять.  
      
    В любом случае выборка данных для sqlite и localStorage разные

  */

  /*-----------------------------------------------------------------------------------------------------*/



//LocalStorage но на sqlite
export class SLStore {
  static nameTable = process.env.REACT_APP_SQLITE_TABLE_SETTINGS as string;

  static setItem:setItemT = (key,  value, options) => {
    return new Promise((resolve, reject) => {
      if(window.cordova){ //INFO: Обновить данные если есть
        let nameTable = SLStore.nameTable;
        Sqlite.getData(nameTable, {sql: `SELECT key FROM ${nameTable} WHERE key="${key}"`})
        .then(({status}) => {
          if(status){
            Sqlite.updateData(nameTable, {key, value}, {where: {key}})
            .then(resolve)
            .catch(reject)
         
          }else{
            Sqlite.setData(nameTable, {key, value}, options)
            .then(resolve)
            .catch(reject)
          }
        })
        .catch(reject);
     
        
      }else{
        try{
          
          localStorage.setItem(
            key, 
            (typeof value === 'object' || typeof value === 'boolean') ? JSON.stringify(value) : value
          );
  
          resolve({status: true, msg: 'Данные сохранены в localStorage'})
        }catch(err){
          reject({status: false, msg: err})
        }
      }
    })
  }
  
  /*-----------------------------------------------------------------------------------------------------*/

  static getItem:getItemT = (key:string) => {
    return new Promise<returnGetDataSqliteT>((resolve, reject) => {
      if(window.cordova){
        Sqlite.getData(SLStore.nameTable, {where: {key}})
        .then(resolve)
        .catch(reject)
      }else{
        try {

          let data = JSON.parse(localStorage.getItem(key as string) || "{}")
          console.dir(data);
          resolve({status: true, value: data, msg: 'Данные из localStorage'});
        } catch (err) {
          reject({status: false,  msg: err});
        }
      }
    })
  }

  /*-----------------------------------------------------------------------------------------------------*/

  static getItems = () => {
    return new Promise<returnGetDataSqliteT>((resolve, reject) => {

      if(window.cordova){
        Sqlite.getData(SLStore.nameTable, {sql: `SELECT * FROM ${SLStore.nameTable}`})   
        .then((data) => {
          console.log('then getAllLocalSetting: ', data);
          resolve(data);
        })
        .catch((err) => {
          console.log('catch getAllLocalSetting: ', err);
          reject(err)
        })
      }else{
        try {
          let config: {[key: string]: any} = {};

          for(let i = 0; i < localStorage.length; i++) {
            
            let keyItem = localStorage.key(i);
            if(keyItem){
              let value = localStorage.getItem(keyItem);
              let val;

              let isTypeForJsonParse = typeof value === "object" || typeof value === "boolean";
              if(isTypeForJsonParse){   val = JSON.stringify(value);  }
              else if(typeof value === 'string'){   val = value.trim();  }
              else{   val = value;   }
                
              Object.assign(config, {[keyItem]: val});
            }
          }

      
          console.dir(config);
          resolve({status: true, value: [config], msg: 'Все данные из localStorage'});
        } catch (err) {
          reject({status: false,  msg: err});
        }
      }
    })
  
  }
 
  

  /*-----------------------------------------------------------------------------------------------------*/
  
  static removeItem = (keys: string[]) => {
    return new Promise((resolve, reject) => {
      if(window.cordova){
        Sqlite.removeData(SLStore.nameTable, {whereArrKey: {name: keys}})
        .then(resolve)
        .catch(reject)
  
      }else{
        try {
          for(let i = 0; i < keys.length; i++){
            localStorage.removeItem(keys[i]);
          }
          resolve({status: true, msg: `Успешное удаление ключей localStorage`})

        } catch (err) {
          reject({status: false, msg: err})
        }
      }
    })
  };
  
  static dropAllData = () => {
    return new Promise((resolve, reject) => {
      if(window.cordova){
        Sqlite.dropTable(SLStore.nameTable)
        .then(resolve)
        .catch(reject)
      }else{
        try {
          localStorage.clear();
          resolve({status: true, msg: `Успешное полное удаление данных в localStorage`})
        } catch (err) {
          reject({status: false, msg: err})
        }
      }
    })
  };

}


(window as any).SLStore = SLStore

==> cordova-sqlite-react-1.1.6.tgz: package/SqliteClass/SLStore.ts <==
import { setItemT, getItemT } from './../@types/commonType';
import { returnGetDataSqliteT } from '../@types/commonType';
import { Sqlite } from './Sqlite';
//INFO: Возможно в будущем localStorage переделать на sqlite3 для pc
  /*
    Структура хранения настроек как в Sqlite так и в localeStorage
    1й вариант. name: 'config' value: "{}", name: 'DarkMode', value: 'true'. В localStorage "config": "{}"
        При каждом внесении изменений придётся доставать, парсить, изменять, закидывать в string и обратно сохранять пачку.
        При выходе удалить ключ config, не затрагивая DarkMode, закинуть default config в state 
    2й вариант. 
      Сохранять каждый ключ   name: "isAuth", value: "true"  в sqlite.  в localeStorage будет так "isAuth": "true"
      Неудобства: 
        Первоначальное получение данных и преобразование в структуру state
        Для поддержания одинаковых ключей в sqlite и localStorage придётся, при удалении ненужных ключей иметь массив нужных
        ключей которые ненужно удалять.  
      
    В любом случае выборка данных для sqlite и localStorage разные

  */

  /*-----------------------------------------------------------------------------------------------------*/



//LocalStorage но на sqlite
export class SLStore {
  static nameTable = process.env.REACT_APP_SQLITE_TABLE_SETTINGS as string;

  static setItem:setItemT = (key,  value, options) => {
    return new Promise((resolve, reject) => {
      if(window.cordova){ //INFO: Обновить данные если есть
        let nameTable = SLStore.nameTable;
        Sqlite.getData(nameTable, {sql: `SELECT key FROM ${nameTable} WHERE key="${key}"`})
        .then(({status}) => {
          if(status){
            Sqlite.updateData(nameTable, {key, value}, {where: {key}})
            .then(resolve)
            .catch(reject)
         
          }else{
            Sqlite.setData(nameTable, {key, value}, options)
            .then(resolve)
            .catch(reject)
          }
        })
        .catch(reject);
     
        
      }else{
        try{
          
          localStorage.setItem(
            key, 
            (typeof value === 'object' || typeof value === 'boolean') ? JSON.stringify(value) : value
          );
  
          resolve({status: true, msg: 'Данные сохранены в localStorage'})
        }catch(err){
          reject({status: false, msg: err})
        }
      }
    })
  }
  
  /*-----------------------------------------------------------------------------------------------------*/

  static getItem:getItemT = (key:string) => {
    return new Promise<returnGetDataSqliteT>((resolve, reject) => {
      if(window.cordova){
        Sqlite.getData(SLStore.nameTable, {where: {key}})
        .then(resolve)
        .catch(reject)
      }else{
        try {

          let data = JSON.parse(localStorage.getItem(key as string) || "{}")
          console.dir(data);
          resolve({status: true, value: data, msg: 'Данные из localStorage'});
        } catch (err) {
          reject({status: false,  msg: err});
        }
      }
    })
  }

  /*-----------------------------------------------------------------------------------------------------*/

  static getItems = () => {
    return new Promise<returnGetDataSqliteT>((resolve, reject) => {

      if(window.cordova){
        Sqlite.getData(SLStore.nameTable, {sql: `SELECT * FROM ${SLStore.nameTable}`})   
        .then((data) => {
          console.log('then getAllLocalSetting: ', data);
          resolve(data);
        })
        .catch((err) => {
          console.log('catch getAllLocalSetting: ', err);
          reject(err)
        })
      }else{
        try {
          let config: {[key: string]: any} = {};

          for(let i = 0; i < localStorage.length; i++) {
            
            let keyItem = localStorage.key(i);
            if(keyItem){
              let value = localStorage.getItem(keyItem);
              let val;

              let isTypeForJsonParse = typeof value === "object" || typeof value === "boolean";
              if(isTypeForJsonParse){   val = JSON.stringify(value);  }
              else if(typeof value === 'string'){   val = value.trim();  }
              else{   val = value;   }
                
              Object.assign(config, {[keyItem]: val});
            }
          }

      
          console.dir(config);
          resolve({status: true, value: [config], msg: 'Все данные из localStorage'});
        } catch (err) {
          reject({status: false,  msg: err});
        }
      }
    })
  
  }
 
  

  /*-----------------------------------------------------------------------------------------------------*/
  
  static removeItem = (keys: string[]) => {
    return new Promise((resolve, reject) => {
      if(window.cordova){
        Sqlite.removeData(SLStore.nameTable, {whereArrKey: {key: keys}})
        .then(resolve)
        .catch(reject)
  
      }else{
        try {
          for(let i = 0; i < keys.length; i++){
            localStorage.removeItem(keys[i]);
          }
          resolve({status: true, msg: `Успешное удаление ключей localStorage`})

        } catch (err) {
          reject({status: false, msg: err})
        }
      }
    })
  };
  
  static dropAllData = () => {
    return new Promise((resolve, reject) => {
      if(window.cordova){
        Sqlite.dropTable(SLStore.nameTable)
        .then(resolve)
        .catch(reject)
      }else{
        try {
          localStorage.clear();
          resolve({status: true, msg: `Успешное полное удаление данных в localStorage`})
        } catch (err) {
          reject({status: false, msg: err})
        }
      }
    })
  };

}


(window as any).SLStore = SLStore
